@@ -1,26 +1,23 @@
-# -*- coding: utf-8 -*-
+# coding: utf-8
+from __future__ import absolute_import
 
-"""
-_base.py
-
-:Created: 5/13/14
-:Author: timic
-"""
 import logging as _logging
-logger = _logging.getLogger(__name__)
-
 import os
 
 from lxml import etree as _etree
-
+from six.moves import map
+from spyne.const.http import HTTP_200
 from spyne.interface.wsdl.wsdl11 import Wsdl11 as _Wsdl11
 from spyne.model.fault import Fault as _Fault
-from spyne.const.http import HTTP_200
+import six
 
-import _utils
-import _xmlns as _ns
-from wsse.protocols import Soap11WSSE
-from fault import ApiError as _ApiError
+from . import _utils
+from . import _xmlns as _ns
+from .fault import ApiError as _ApiError
+from .wsse.protocols import Soap11WSSE
+
+
+logger = _logging.getLogger(__name__)
 
 
 class BaseSmev(Soap11WSSE):
@@ -66,10 +63,12 @@ class BaseSmev(Soap11WSSE):
                    (ctx.udc.in_smev_message_document, message_data))):
             raise _Fault("SMEV-100010", "Invalid configuration!")
 
-        map(self._validate_smev_element, filter(_utils.notisnone, (
-            ctx.udc.in_smev_message_document,
-            ctx.udc.in_smev_header_document,
-            message_data)))
+        for element in (ctx.udc.in_smev_message_document,
+                        ctx.udc.in_smev_header_document,
+                        message_data):
+            if element is not None:
+                self._validate_smev_element(element)
+
         method_data = message_data.find(
             ".//{{{smev}}}AppData".format(**self._ns)).getchildren()
         method = in_document.find(
@@ -105,13 +104,21 @@ class BaseSmev(Soap11WSSE):
         if issubclass(cls, _ApiError):
             message = _etree.SubElement(
                 parent_elt, "{{{0}}}{1}".format(tns, value.messageName))
-            error = _etree.SubElement(message, "{{{0}}}{1}".format(tns, "Error"))
+            error = _etree.SubElement(
+                message, "{{{0}}}{1}".format(tns, "Error")
+            )
             _etree.SubElement(
                 error, "{{{0}}}{1}".format(tns, "errorCode")
             ).text = value.errorCode
+
+            if not isinstance(value.errorMessage, six.text_type):
+                error_msg = value.errorMessage.decode('UTF-8')
+            else:
+                error_msg = value.errorMessage
+
             _etree.SubElement(
                 error, "{{{0}}}{1}".format(tns, "errorMessage")
-            ).text = value.errorMessage
+            ).text = error_msg
         else:
             super(BaseSmev, self).to_parent_element(
                 cls, value, tns, parent_elt, *args, **kwargs)
@@ -121,13 +128,21 @@ class BaseSmev(Soap11WSSE):
         if issubclass(cls, _ApiError):
             message = _etree.SubElement(
                 parent, "{{{0}}}{1}".format(ns, inst.messageName))
-            error = _etree.SubElement(message, "{{{0}}}{1}".format(ns, "Error"))
+            error = _etree.SubElement(
+                message, "{{{0}}}{1}".format(ns, "Error")
+            )
             _etree.SubElement(
                 error, "{{{0}}}{1}".format(ns, "errorCode")
             ).text = inst.errorCode
+
+            if not isinstance(inst.errorMessage, six.text_type):
+                error_msg = inst.errorMessage.decode('UTF-8')
+            else:
+                error_msg = inst.errorMessage
+
             _etree.SubElement(
                 error, "{{{0}}}{1}".format(ns, "errorMessage")
-            ).text = inst.errorMessage
+            ).text = error_msg
         else:
             return super(BaseSmev, self).to_parent(
                 ctx, cls, inst, parent, ns, *args, **kwargs)
@@ -213,6 +228,7 @@ class BaseSmevWsdl(_Wsdl11):
                 0, xop_include_schema)
 
         self._add_smev_headers(self.root_elt)
+        # pylint: disable=attribute-defined-outside-init
         self._Wsdl11__wsdl = _etree.tostring(
             self.root_elt, encoding='UTF-8')
 
@@ -267,4 +283,4 @@ class BaseSmevWsdl(_Wsdl11):
                 nsmap={"smev": self.smev_ns},
                 message="tns:SmevHeader",
                 part="SmevHeader",
-                use="literal")
\ No newline at end of file
+                use="literal")
