@@ -1,19 +1,16 @@
-# -*- coding: utf-8 -*-
-
-"""
-application.py
-
-:Created: 4/3/14
-:Author: timic
-"""
-import logging
-logger = logging.getLogger(__name__)
+# coding: utf-8
+from __future__ import absolute_import
 
 from traceback import format_exc
+import logging
 
-from spyne.model.fault import Fault
 from spyne.application import Application as SpyneApplication
 from spyne.error import InternalError
+from spyne.model.fault import Fault
+import six
+
+
+logger = logging.getLogger(__name__)
 
 
 class Application(SpyneApplication):
@@ -27,13 +24,11 @@ class Application(SpyneApplication):
     def call_wrapper(self, ctx):
         try:
             return super(Application, self).call_wrapper(ctx)
-        except Fault, e:
+        except Fault as e:
             logger.exception(e)
             raise
-        except Exception, e:
-            e_text = unicode(format_exc(), errors="ignore")
+        except Exception as e:
+            e_text = six.text_type(format_exc(), errors="ignore")
             self.event_manager.fire_event("method_call_exception", e_text)
             logger.exception(e)
             raise InternalError(e)
-
-
