@@ -1,20 +1,23 @@
-# -*- coding: utf-8 -*-
+# coding: utf-8
+from __future__ import absolute_import
 
-"""
-:Created: 3/12/14
-:Author: timic
-"""
 import datetime
 import os
 
 from lxml import etree
+import six
 
-from .._base import BaseSmev, BaseSmevWsdl
-from .._utils import EmptyCtx, el_name_with_ns
-from .. fault import ApiError as _ApiError
 from .. import _xmlns as ns
+from .._base import BaseSmev
+from .._base import BaseSmevWsdl
+from .._utils import EmptyCtx
+from .._utils import el_name_with_ns
+from ..fault import ApiError as _ApiError
+from .model import AppDocument
+from .model import HeaderType
+from .model import MessageType
+from .model import ServiceType
 
-from model import MessageType, ServiceType, HeaderType, AppDocument
 
 try:
     from spyne.protocol.xml.model import complex_from_element as _spyne_cfe
@@ -86,7 +89,7 @@ class Smev256(BaseSmev):
         :param ctx: Сквозной контекст метода
         :rtype: lxml.etree.Element
         """
-
+        # pylint: disable=too-many-locals
         # TODO: сделать нормальный биндинг
 
         if getattr(ctx, "udc", None) is None:
@@ -143,9 +146,12 @@ class Smev256(BaseSmev):
             "Status")).text = ctx.udc.out_smev_message.Status or status
         etree.SubElement(
             root, SMEV("Date")).text = datetime.datetime.utcnow().isoformat()
-        etree.SubElement(
-            root, SMEV("ExchangeType")).text = self.smev_params.get(
-                "ExchangeType", "0")
+
+        exchange_type = (
+            self.smev_params.get("ExchangeType") or
+            six.text_type(ctx.udc.in_smev_message.ExchangeType) or
+            "0")
+        etree.SubElement(root, SMEV("ExchangeType")).text = exchange_type
 
         request_id_ref = (
             ctx.udc.out_smev_message.RequestIdRef
@@ -160,15 +166,20 @@ class Smev256(BaseSmev):
                 root, SMEV("OriginRequestIdRef")).text = origin_request_id_ref
 
         service_code = (
-            ctx.udc.out_smev_message.ServiceCode
-            or self.smev_params.get("ServiceCode"))
+            ctx.udc.out_smev_message.ServiceCode or
+            self.smev_params.get("ServiceCode") or
+            ctx.udc.in_smev_message.ServiceCode)
         if service_code:
             etree.SubElement(root, SMEV("ServiceCode")).text = service_code
 
-        if ctx.udc.out_smev_message.CaseNumber:
+        case_number = (
+            ctx.udc.out_smev_message.CaseNumber or
+            ctx.udc.in_smev_message.CaseNumber)
+        if case_number:
             etree.SubElement(
                 root, SMEV("CaseNumber")
-            ).text = ctx.udc.out_smev_message.CaseNumber or ""
+            ).text = case_number or ""
+
         if "OKTMO" in self.smev_params:
             etree.SubElement(
                 root, SMEV("OKTMO")).text = self.smev_params.get("OKTMO", "")
@@ -200,4 +211,4 @@ class Smev256(BaseSmev):
                 app_document, SMEV("BinaryData")
             ).text = ctx.udc.out_smev_appdoc.BinaryData
 
-        return root
\ No newline at end of file
+        return root
