@@ -1,22 +1,18 @@
-# -*- coding: utf-8 -*-
-
-"""               
-utils.py
-                  
-:Created: 03 Jul 2014  
-:Author: tim    
-"""
+# coding: utf-8
+from __future__ import absolute_import
 
 from copy import deepcopy as _deepcopy
-import base64 as _base64
 from functools import partial as _partial
+import base64 as _base64
 import uuid as _uuid
 
 from lxml import etree as _etree
+import six
 
-from spyne_smev import crypto as _crypto
 from spyne_smev import _utils
 from spyne_smev import _xmlns
+from spyne_smev import crypto as _crypto
+
 
 _nsmap = _xmlns.nsmap
 
@@ -28,7 +24,9 @@ _c14n_nsmap = {
     (False, True): _xmlns.xml_c14n_wc,
 }
 
-_c14n_params = dict((v, k) for k, v in _c14n_nsmap.iteritems())
+_c14n_params = dict(
+    (v, k) for k, v in six.iteritems(_c14n_nsmap)
+)
 
 _digest_method_nsmap = {
     "md_gost94": _xmlns.gost94,
@@ -38,7 +36,9 @@ _digest_method_nsmap = {
     "md5": _xmlns.md5,
 }
 
-_digest_method_names = dict((v, k) for k, v in _digest_method_nsmap.items())
+_digest_method_names = dict(
+    (v, k) for k, v in six.iteritems(_digest_method_nsmap)
+)
 
 _signature_method_nsmap = {
     "RSA-SHA1": _xmlns.rsa_sha1,
@@ -72,13 +72,17 @@ def _construct_wsse_header(
         actor="http://smev.gosuslugi.ru/actors/smev",
         digest_method="sha1",
         signature_method=None):
+    # pylint: disable=too-many-locals
     digest_method_ns = _digest_method_nsmap.get(digest_method, None)
     if digest_method_ns is None:
         raise ValueError("No such digest method: {0}".format(digest_method))
 
     if not signature_method:
         signature_method = _crypto.get_signature_algorithm_name(certificate)
-    signature_method_ns = _signature_method_nsmap.get(signature_method, None)
+    signature_method_ns = _utils.get_dict_value(
+        _signature_method_nsmap,
+        signature_method
+    )
     if signature_method_ns is None:
         raise ValueError(
             "No such signature method: {0}".format(signature_method))
@@ -154,7 +158,7 @@ def sign_document(
     :return: Signed document
     :rtype: lxml.etree.Element
     """
-
+    # pylint: disable=too-many-locals
     _c14n = _partial(
         _etree.tostring, method="c14n",
         exclusive=c14n_exclusive, with_comments=c14n_with_comments)
@@ -196,8 +200,11 @@ def sign_document(
         "./{{{soapenv}}}Header/{{{wsse}}}Security"
         "/{{{ds}}}Signature/{{{ds}}}SignedInfo".format(**_nsmap))
     signature_algorithm = _crypto.get_signature_algorithm_name(cert_data)
-    signature_algorithm = _signature_method_exclusions.get(
-        signature_algorithm, signature_algorithm)
+    signature_algorithm = _utils.get_dict_value(
+        _signature_method_exclusions,
+        signature_algorithm,
+        signature_algorithm
+    )
     signature_value = _base64.b64encode(_crypto.sign(
         _c14n(sign_info_node), pkey_data, pkey_pass, signature_algorithm))
     sign_val_node = out_document.find(
@@ -216,7 +223,7 @@ def verify_document(document, certificate):
     :type document: lxml.etree.Element
     :raises: ValueError, spyne_smev.crypto.InvalidSignature
     """
-
+    # pylint: disable=too-many-locals, too-many-branches, too-many-statements
     body = document.find("./{{{soapenv}}}Body".format(**_nsmap))
     if body is None:
         raise ValueError(
@@ -276,10 +283,10 @@ def verify_document(document, certificate):
     exc_c14n, with_comments = _c14n_params.get(c14n_method)
     inc_ns = transform.find("{{{0}}}InclusiveNamespaces".format(
         _xmlns.exc_c14n))
-    if not inc_ns is None:
+    if inc_ns is not None:
         inc_ns_prefixes = inc_ns.attrib["PrefixList"].split()
         inc_ns_map = dict(
-            (k, v) for k, v in document.nsmap.iteritems()
+            (k, v) for k, v in six.iteritems(document.nsmap)
             if k in inc_ns_prefixes)
     else:
         inc_ns_map = None
@@ -289,7 +296,7 @@ def verify_document(document, certificate):
              inclusive_ns_prefixes=inc_ns_map),
         digest_name))
 
-    if body_digest != digest_value.text:
+    if body_digest.decode() != digest_value.text:
         raise _crypto.InvalidSignature("Invalid `Body` digest!")
     signature_method = document.find(
         ".//{{{ds}}}SignatureMethod".format(**_nsmap))
@@ -315,10 +322,10 @@ def verify_document(document, certificate):
     exc_c14n, with_comments = _c14n_params.get(c14n_method)
     inc_ns = c14n_method_node.find("{{{0}}}InclusiveNamespaces".format(
         _xmlns.exc_c14n))
-    if not inc_ns is None:
+    if inc_ns is not None:
         inc_ns_prefixes = inc_ns.attrib["PrefixList"].split()
         inc_ns_map = dict(
-            (k, v) for k, v in document.nsmap.iteritems()
+            (k, v) for k, v in six.iteritems(document.nsmap)
             if k in inc_ns_prefixes)
     else:
         inc_ns_map = None
@@ -327,4 +334,4 @@ def verify_document(document, certificate):
              inclusive_ns_prefixes=inc_ns_map),
         certificate,
         _base64.b64decode(signature.text),
-        digest_name)
\ No newline at end of file
+        digest_name)
